@@ -77,7 +77,11 @@ class TaskOnKart(luigi.Task):
         return tasks or []  # when tasks is empty dict, then this returns empty list.
 
     def make_task_instance_dictionary(self) -> Dict[str, 'TaskOnKart']:
-        return {key: var for key, var in vars(self).items() if isinstance(var, TaskOnKart)}
+        return {key: var for key, var in vars(self).items() if self.is_task_on_kart(var)}
+
+    @staticmethod
+    def is_task_on_kart(value):
+        return isinstance(value, TaskOnKart) or (isinstance(value, list) and bool(value) and all([isinstance(v, TaskOnKart) for v in value]))
 
     @classmethod
     def _add_configuration(cls, kwargs, section):
